@@ -142,7 +142,7 @@ setMethod("dwiMixtensor","dtiData",function(object, maxcomp=3,
                 s0=double(nvox),
                 vsi=double(nvox),
                 mask=logical(nvox),
-                DUPL=FALSE,
+                DUPL=TRUE,
                 PACKAGE="dti")[c("siq","s0","vsi","mask")]
       t2 <- Sys.time()
       cat(difftime(t2,t1),"for",nvox,"voxel\n")
@@ -165,7 +165,7 @@ setMethod("dwiMixtensor","dtiData",function(object, maxcomp=3,
                 as.integer(object@level),
                 siq=double(nvox*(ngrad0+3)),
                 as.integer(ngrad0+3),
-                DUPL=FALSE,
+                DUPL=TRUE,
                 PACKAGE="dti")$siq,ngrad0+3,nvox)
       t2 <- Sys.time()
       cat(difftime(t2,t1),"for",nvox,"voxel\n")
@@ -284,7 +284,7 @@ setMethod("dwiMixtensor","dtiData",function(object, maxcomp=3,
                  order   = integer(nvoxm),   # selected order of mixture
                  lev     = double(2*nvoxm),         # logarithmic eigenvalues
                  mix     = double(maxcomp*nvoxm),   # mixture weights
-                 DUPL=FALSE, PACKAGE="dti")[c("sigma2","orient","order","lev","mix")]
+                 DUPL=TRUE, PACKAGE="dti")[c("sigma2","orient","order","lev","mix")]
          cat("End parameter estimation and model selection ",format(Sys.time()),"\n")
          sigma2 <-  array(0,ddim)
          sigma2[mask] <- z$sigma2
@@ -348,7 +348,7 @@ setMethod("dwiMixtensor","dtiData",function(object, maxcomp=3,
           orient  = double(2*maxcomp*nvoxm),#orient_ret phi/theta for all mixture tensors
           order   = integer(nvoxm),#order_ret selected order of mixture
           mix     = double(maxcomp*nvoxm),#mixture weights
-          DUPL=FALSE, PACKAGE="dti")[c("sigma2","orient","order","alpha","lambda","mix")],
+          DUPL=TRUE, PACKAGE="dti")[c("sigma2","orient","order","alpha","lambda","mix")],
           .C("mixtrl1", 
           as.integer(nvoxm),#n1
           as.integer(siind[,mask]),#siind 
@@ -369,7 +369,7 @@ setMethod("dwiMixtensor","dtiData",function(object, maxcomp=3,
           order   = integer(nvoxm),#order_ret selected order of mixture
           lambda  = double(nvoxm),#lambda_ret lambda_2 
           mix     = double(maxcomp*nvoxm),#mixture weights
-          DUPL=FALSE, PACKAGE="dti")[c("sigma2","orient","order","alpha","lambda","mix")],
+          DUPL=TRUE, PACKAGE="dti")[c("sigma2","orient","order","alpha","lambda","mix")],
           .C("mixtrl2", 
           as.integer(nvoxm),#n1
           as.integer(siind[,mask]),#siind 
@@ -391,7 +391,7 @@ setMethod("dwiMixtensor","dtiData",function(object, maxcomp=3,
           alpha   = double(nvoxm),#alpha_ret alpha=(lambda_1-lambda_2)/lambda_2 
           lambda  = double(nvoxm),#lambda_ret lambda_2 
           mix     = double(maxcomp*nvoxm),#mixture weights
-          DUPL=FALSE, PACKAGE="dti")[c("sigma2","orient","order","alpha","lambda","mix")])
+          DUPL=TRUE, PACKAGE="dti")[c("sigma2","orient","order","alpha","lambda","mix")])
       cat("End parameter estimation and model selection (C-code)",format(Sys.time()),"\n")
       sigma2 <-  array(0,ddim)
       sigma2[mask] <- z$sigma2
@@ -491,7 +491,7 @@ selisample <- function(ngrad,maxcomp,nguess,dgrad,maxc){
                 as.integer(dim(dgrad)[1]),
                 ind = logical(nguess),
                 as.double(maxc),
-                DUPL=FALSE,
+                DUPL=TRUE,
                 PACKAGE="dti")$ind 
    .Random.seed <- saved.seed
    }
@@ -533,7 +533,7 @@ maxc=.866,nguess=100,mc.cores = setCores(,reprt=FALSE)){
                    as.integer(nvoxel),
                    as.logical(landir),
                    iandir=integer(prod(ddim)),
-                   DUPL=FALSE,
+                   DUPL=TRUE,
                    PACKAGE="dti")$iandir
    isample0 <- selisample(nvico,maxcomp,nguess,dgradi,maxc)
    if(maxcomp>1) isample1 <- selisample(nvico,maxcomp-1,nguess,dgradi,maxc)
@@ -572,7 +572,7 @@ maxc=.866,nguess=100,mc.cores = setCores(,reprt=FALSE)){
                        krit=double(nvoxel),
                        as.integer(maxcomp+2),
                        as.logical(mask&!landir),
-                       DUP=FALSE,
+                       DUP=TRUE,
                        PACKAGE="dti")[c("siind","krit")]
          dim(z$siind) <- c(maxcomp+2,nvoxel)
          siind[,!landir] <- z$siind[,!landir]
@@ -619,7 +619,7 @@ maxc=.866,nguess=100,mc.cores = setCores(,reprt=FALSE)){
                           as.logical(mask&landir),
                           as.double(dgradi),
                           as.double(maxc),
-                          DUP=FALSE,
+                          DUP=TRUE,
                           PACKAGE="dti")[c("siind","krit")]
             dim(z$siind) <- c(maxcomp+2,nvoxel)
             siind[,landir] <- z$siind[,landir]
@@ -694,95 +694,95 @@ getsiind2 <- function(si,sigma2,grad,bv,vico,alpha,lambda,maxcomp=3,maxc=.866,ng
      krit=array(krit,dim(si)[-1]))
 }
 
-mtrisk <- function(par,dwiobj,ix=1,iy=1,iz=1){
-   s0ind <- dwiobj@s0ind
-   grad <-  dwiobj@gradient[,-s0ind]
-   bv <- dwiobj@bvalue[-s0ind]
-   bv <- bv/max(bv)
-   si <- dwiobj@si[ix,iy,iz,]
-   siq <- si[-s0ind]/mean(si[s0ind])
-   ng <- length(bv)
-   npar <- length(par)
-   rsk <- .Fortran("rskmixl2",
-                as.double(par),
-                as.integer(npar),
-                as.double(siq),
-                as.double(grad),
-                as.double(bv),
-                as.integer(ng),
-                rsk=double(1),
-                DUPL=FALSE,
-                PACKAGE="dti")$rsk   
-   rsk
-}
-mtgrad <- function(par,dwiobj,ix=1,iy=1,iz=1,eps=1e-4){
-   s0ind <- dwiobj@s0ind
-   grad <-  dwiobj@gradient[,-s0ind]
-   bv <- dwiobj@bvalue[-s0ind]
-   bv <- bv/max(bv)
-   si <- dwiobj@si[ix,iy,iz,]
-   siq <- si[-s0ind]/mean(si[s0ind])
-   ng <- length(bv)
-   npar <- length(par)
-   drsk <- .Fortran("drskml2",
-                as.double(par),
-                as.integer(npar),
-                as.double(siq),
-                as.double(grad),
-                as.double(bv),
-                as.integer(ng),
-                drsk=double(npar),
-                DUPL=FALSE,
-                PACKAGE="dti")$drsk   
-   drsk
-}
-mtgrad1 <- function(par,dwiobj,ix=1,iy=1,iz=1,eps=1e-4){
-   s0ind <- dwiobj@s0ind
-   grad <-  dwiobj@gradient[,-s0ind]
-   bv <- dwiobj@bvalue[-s0ind]
-   bv <- bv/max(bv)
-   si <- dwiobj@si[ix,iy,iz,]
-   siq <- si[-s0ind]/mean(si[s0ind])
-   ng <- length(bv)
-   npar <- length(par)
-   drsk <- .Fortran("drskml2",
-                as.double(par),
-                as.integer(npar),
-                as.double(siq),
-                as.double(grad),
-                as.double(bv),
-                as.integer(ng),
-                drsk=double(npar),
-                DUPL=FALSE,
-                PACKAGE="dti")$drsk   
-   rsk <- .Fortran("rskmixl2",
-                as.double(par),
-                as.integer(npar),
-                as.double(siq),
-                as.double(grad),
-                as.double(bv),
-                as.integer(ng),
-                rsk=double(1),
-                DUPL=FALSE,
-                PACKAGE="dti")$rsk   
-   drskn <- drsk
-   for(i in 1:npar){
-      par0 <- par
-      par0[i] <- par[i]+eps
-      rsk0 <- .Fortran("rskmixl2",
-                as.double(par0),
-                as.integer(npar),
-                as.double(siq),
-                as.double(grad),
-                as.double(bv),
-                as.integer(ng),
-                rsk=double(1),
-                DUPL=FALSE,
-                PACKAGE="dti")$rsk   
-      drskn[i] <- (rsk0-rsk)/eps
-   }
-   cat("parameters, analytic gradient, numeric gradient\n")
-   print(rbind(par,drsk,drskn))
-   list(drskn=drskn)
-}
+# mtrisk <- function(par,dwiobj,ix=1,iy=1,iz=1){
+#    s0ind <- dwiobj@s0ind
+#    grad <-  dwiobj@gradient[,-s0ind]
+#    bv <- dwiobj@bvalue[-s0ind]
+#    bv <- bv/max(bv)
+#    si <- dwiobj@si[ix,iy,iz,]
+#    siq <- si[-s0ind]/mean(si[s0ind])
+#    ng <- length(bv)
+#    npar <- length(par)
+#    rsk <- .Fortran("rskmixl2",
+#                 as.double(par),
+#                 as.integer(npar),
+#                 as.double(siq),
+#                 as.double(grad),
+#                 as.double(bv),
+#                 as.integer(ng),
+#                 rsk=double(1),
+#                 DUPL=TRUE,
+#                 PACKAGE="dti")$rsk   
+#    rsk
+# }
+# mtgrad <- function(par,dwiobj,ix=1,iy=1,iz=1,eps=1e-4){
+#    s0ind <- dwiobj@s0ind
+#    grad <-  dwiobj@gradient[,-s0ind]
+#    bv <- dwiobj@bvalue[-s0ind]
+#    bv <- bv/max(bv)
+#    si <- dwiobj@si[ix,iy,iz,]
+#    siq <- si[-s0ind]/mean(si[s0ind])
+#    ng <- length(bv)
+#    npar <- length(par)
+#    drsk <- .Fortran("drskml2",
+#                 as.double(par),
+#                 as.integer(npar),
+#                 as.double(siq),
+#                 as.double(grad),
+#                 as.double(bv),
+#                 as.integer(ng),
+#                 drsk=double(npar),
+#                 DUPL=TRUE,
+#                 PACKAGE="dti")$drsk   
+#    drsk
+# }
+# mtgrad1 <- function(par,dwiobj,ix=1,iy=1,iz=1,eps=1e-4){
+#    s0ind <- dwiobj@s0ind
+#    grad <-  dwiobj@gradient[,-s0ind]
+#    bv <- dwiobj@bvalue[-s0ind]
+#    bv <- bv/max(bv)
+#    si <- dwiobj@si[ix,iy,iz,]
+#    siq <- si[-s0ind]/mean(si[s0ind])
+#    ng <- length(bv)
+#    npar <- length(par)
+#    drsk <- .Fortran("drskml2",
+#                 as.double(par),
+#                 as.integer(npar),
+#                 as.double(siq),
+#                 as.double(grad),
+#                 as.double(bv),
+#                 as.integer(ng),
+#                 drsk=double(npar),
+#                 DUPL=TRUE,
+#                 PACKAGE="dti")$drsk   
+#    rsk <- .Fortran("rskmixl2",
+#                 as.double(par),
+#                 as.integer(npar),
+#                 as.double(siq),
+#                 as.double(grad),
+#                 as.double(bv),
+#                 as.integer(ng),
+#                 rsk=double(1),
+#                 DUPL=TRUE,
+#                 PACKAGE="dti")$rsk   
+#    drskn <- drsk
+#    for(i in 1:npar){
+#       par0 <- par
+#       par0[i] <- par[i]+eps
+#       rsk0 <- .Fortran("rskmixl2",
+#                 as.double(par0),
+#                 as.integer(npar),
+#                 as.double(siq),
+#                 as.double(grad),
+#                 as.double(bv),
+#                 as.integer(ng),
+#                 rsk=double(1),
+#                 DUPL=TRUE,
+#                 PACKAGE="dti")$rsk   
+#       drskn[i] <- (rsk0-rsk)/eps
+#    }
+#    cat("parameters, analytic gradient, numeric gradient\n")
+#    print(rbind(par,drsk,drskn))
+#    list(drskn=drskn)
+# }
 
