@@ -1,4 +1,4 @@
-      subroutine mediansm(y,n1,n2,n3,ind,nind,work,ncores,yout)
+      subroutine mediansm(y,mask,n1,n2,n3,ind,nind,work,ncores,yout)
 C
 C
 C   3D median smoother of y with neighborhood defined by ind
@@ -7,6 +7,7 @@ C   size of work needs to be 2*nind
 C
       implicit logical (a-z)
       integer n1,n2,n3,nind,ind(3,nind),ncores
+      logical mask(n1,n2,n3)
       real*8 y(n1,n2,n3),yout(n1,n2,n3),work(nind,ncores)
       integer i1,i2,i3,j1,j2,j3,j,k,thrednr
 !$      integer omp_get_thread_num
@@ -18,6 +19,10 @@ C$OMP DO SCHEDULE(GUIDED)
 !$         thrednr = omp_get_thread_num()+1
          DO i2=1,n2
             DO i3=1,n3
+               if(.not.mask(i1,i2,i3)) THEN
+                  yout(i1,i2,i3) = y(i1,i2,i3)
+                  CYCLE
+               ENDIF
                k=0
                DO j=1,nind
                   j1=i1+ind(1,j)
@@ -26,15 +31,20 @@ C$OMP DO SCHEDULE(GUIDED)
                   if(j2.le.0.or.j2.gt.n2) CYCLE
                   j3=i3+ind(3,j)
                   if(j3.le.0.or.j3.gt.n3) CYCLE
+                  if(y(j1,j2,j3).le.0.d0) CYCLE
                   k=k+1
                   work(k,thrednr)=y(j1,j2,j3)
                END DO
-               call qsort3(work(1,thrednr),1,k)
-               IF (mod(k,2) == 0) THEN    
-                  yout(i1,i2,i3) = 
+               IF(k.gt.1) THEN
+                  call qsort3(work(1,thrednr),1,k)
+                  IF (mod(k,2) == 0) THEN    
+                     yout(i1,i2,i3) = 
      1               (work(k/2,thrednr)+work(k/2+1,thrednr))/2.d0
+                  ELSE
+                     yout(i1,i2,i3) = work(k/2+1,thrednr)
+                  END IF
                ELSE
-                  yout(i1,i2,i3) = work(k/2+1,thrednr)
+                  yout(i1,i2,i3) = y(i1,i2,i3)
                END IF
             END DO
          END DO
@@ -44,8 +54,8 @@ C$OMP END PARALLEL
 C$OMP FLUSH(yout)
       return
       end
-      subroutine awslchi(s,th,ni,sigma,fns,L,mask,n1,n2,n3,ind,w,nw,
-     1                minni,wad,sad,lambda,nthreds,iL,work,thn,sigman)
+      subroutine awslchi2(s,ksi,ni,sigma,vpar,L,mask,n1,n2,n3,ind,
+     1      w,nw,minni,wad,sad,lambda,nthreds,iL,work,thn,sigman,ksin)
 C
 C  local variance estimation using (adaptive) weighted likelihood
 C
@@ -70,12 +80,13 @@ C
       implicit logical (a-z)
       integer n1,n2,n3,nw,ind(3,nw),nthreds,iL
       logical mask(n1,n2,n3)
-      real*8 s(n1,n2,n3),th(n1,n2,n3),ni(n1*n2*n3),thn(n1*n2*n3),
-     1  fns(n1,n2,n3),sigman(n1*n2*n3),lambda,w(nw),sigma(n1,n2,n3),
-     2  wad(nw,nthreds),sad(nw,nthreds),L,minni,work(iL,nthreds)
+      real*8 s(n1,n2,n3),ni(n1*n2*n3),thn(n1*n2*n3),
+     1  ksi(n1,n2,n3),sigman(n1*n2*n3),lambda,w(nw),sigma(n1,n2,n3),
+     2  wad(nw,nthreds),sad(nw,nthreds),L,minni,work(iL,nthreds),
+     3  ksin(n1,n2,n3),vpar(6)
       integer i1,i2,i3,j1,j2,j3,i,j,jj,n,maxit,thrednr
-      real*8 z,sw,sws,sws2,sj,thi,wj,kval,fnsi,sgi,tol,low,up,ksi,
-     1       xmin,fmin
+      real*8 z,sw,sws,sws2,sj,thi,wj,kval,fnsi,sgi,tol,low,up,
+     1       fmin,sgi2,vz,thi2,thj2,fnsj,thj
 !$      integer omp_get_thread_num
 !$      external omp_get_thread_num
       n = n1*n2*n3
@@ -85,8 +96,8 @@ C
 C  precompute values of lgamma(corrected df/2) in each voxel
 C$OMP PARALLEL DEFAULT(SHARED)
 C$OMP& FIRSTPRIVATE(iL,L,minni,n1,n2,n3,maxit)
-C$OMP& PRIVATE(i,j,i1,i2,i3,j1,j2,j3,z,sw,sws,sws2,thi,kval,
-C$OMP& wj,sj,thrednr,fnsi,low,up,tol,sgi,ksi,jj,xmin,fmin)
+C$OMP& PRIVATE(i,j,i1,i2,i3,j1,j2,j3,z,sw,sws,sws2,thi,kval,thi2,thj2,
+C$OMP& wj,sj,thrednr,fnsi,low,up,tol,sgi,jj,fmin,sgi2,vz,thj,fnsj)
 C$OMP DO SCHEDULE(GUIDED)
       DO i=1,n
          i1=mod(i,n1)
@@ -100,11 +111,18 @@ C$OMP DO SCHEDULE(GUIDED)
          sws=0.d0
          sws2=0.d0
          sgi=sigma(i1,i2,i3)
-         thi = th(i1,i2,i3)
+         sgi2=sgi*sgi
+         thi = sqrt(max(0.d0,ksi(i1,i2,i3)/sgi2-2.d0*L))
          thn(i) = thi
-         fnsi = fns(i1,i2,i3)
+         if(thi.gt.vpar(1)) THEN
+            thi2 = thi*thi
+            vz = vpar(3)*thi+vpar(4)*thi2+vpar(5)*thi*thi2+vpar(6)
+            fnsi = max(vpar(2),vz/(vz+1))
+         ELSE
+            fnsi = vpar(2)
+         END IF
 C   thats the estimated standard deviation of s(i1,i2,i3)
-         kval = lambda/ni(i)*sgi*sgi
+         kval = lambda/ni(i)
          jj = 0
          DO j=1,nw
             wad(j,thrednr)=0.d0
@@ -115,8 +133,16 @@ C   thats the estimated standard deviation of s(i1,i2,i3)
             j3=i3+ind(3,j)
             if(j3.le.0.or.j3.gt.n3) CYCLE
             wj=w(j)
-            z=thi-th(j1,j2,j3)
-            z=z*z/(fnsi+fns(j1,j2,j3))
+            thj = sqrt(max(0.d0,ksi(j1,j2,j3)/sgi2-2.d0*L))
+            if(thj.gt.vpar(1)) THEN
+               thj2 = thj*thj
+               vz = vpar(3)*thj+vpar(4)*thj2+vpar(5)*thj*thj2+vpar(6)
+               fnsj = max(vpar(2),vz/(vz+1))
+            ELSE
+               fnsj = vpar(2)
+            END IF            
+            z=thi-thj
+            z=z*z/(fnsi+fnsj)
             if(z.ge.kval) CYCLE
             wj=wj*min(1.d0,2.d0-2.d0*z/kval)
             sw=sw+wj
@@ -128,17 +154,16 @@ C   thats the estimated standard deviation of s(i1,i2,i3)
             sad(jj,thrednr)=sj
          END DO
          ni(i) = sw
-         thn(i) = sws/sw
          if(sw.gt.minni) THEN
-            ksi = sws2/sw
+            ksin(i1,i2,i3) = sws2/sw
+C needed for the next iteration 
             low = sgi/1d1
             up = sgi*1d1
             call localmin(low,up,wad(1,thrednr),sad(1,thrednr),L,jj,
-     1                    tol,maxit,work(1,thrednr),xmin,fmin)
-            sigman(i)=xmin
-         ELSE
-            sigman(i)=sgi
+     1                    tol,maxit,work(1,thrednr),sgi,fmin)
          END IF
+         sigman(i)=sgi
+         thn(i) = sqrt(max(0.d0,ksin(i1,i2,i3)-2.d0*sgi*sgi*L))
       END DO
 C$OMP END DO NOWAIT
 C$OMP END PARALLEL
@@ -186,11 +211,11 @@ C$OMP DO SCHEDULE(GUIDED)
          i2=mod((i-i1)/n1+1,n2)
          if(i2.eq.0) i2=n2
          i3=(i-i1-(i2-1)*n1)/n1/n2+1         
+         if(.not.mask(i1,i2,i3)) CYCLE
          sgi=sigma(i1,i2,i3)
          sigman(i)=sgi
          thi = th(i1,i2,i3)
          thn(i) = thi
-         if(.not.mask(i1,i2,i3)) CYCLE
          sw=0.d0
          sws=0.d0
          sws2=0.d0
@@ -429,16 +454,19 @@ C
       ih1=int(h)
       ih2=int(h*vext(1))
       ih3=int(h*vext(2))
-      Do i1=1+ih1,n1-ih1
-         Do i2=1+ih2,n2-ih2
-            Do i3=1+ih3,n3-ih3
+      Do i1=1,n1
+         Do i2=1,n2
+            Do i3=1,n3
                if(mask(i1,i2,i3)) THEN
                   ni=0
                   m1=0.d0
                   m2=0.d0
                   DO j1=i1-ih1,i1+ih1
+                     if(j1.le.0.or.j1.gt.n1) CYCLE
                      DO j2=i2-ih2,i2+ih2
+                        if(j2.le.0.or.j2.gt.n2) CYCLE
                         DO j3=i3-ih3,i3+ih3
+                           if(j3.le.0.or.j3.gt.n3) CYCLE
                            if(mask(j1,j2,j3)) THEN
                               z=y(j1,j2,j3)
                               m1=m1+z
@@ -477,15 +505,18 @@ C
       ih1=int(h)
       ih2=int(h*vext(1))
       ih3=int(h*vext(2))
-      Do i1=1+ih1,n1-ih1
-         Do i2=1+ih2,n2-ih2
-            Do i3=1+ih3,n3-ih3
+      Do i1=1,n1
+         Do i2=1,n2
+            Do i3=1,n3
                if(mask(i1,i2,i3)) THEN
                   ni=0
                   m1=0.d0
                   DO j1=i1-ih1,i1+ih1
+                     if(j1.le.0.or.j1.gt.n1) CYCLE
                      DO j2=i2-ih2,i2+ih2
+                        if(j2.le.0.or.j2.gt.n2) CYCLE
                         DO j3=i3-ih3,i3+ih3
+                           if(j3.le.0.or.j3.gt.n3) CYCLE
                            if(mask(j1,j2,j3)) THEN
                               m1=m1+y(j1,j2,j3)
                               ni=ni+1
@@ -502,3 +533,44 @@ C
       END DO
       RETURN
       END
+      subroutine afmodem2(y,n1,n2,n3,mask,h,vext,sm)
+C
+C   Aja-Fernandez Mode Vn (6)
+C
+      implicit logical (a-z)
+      integer n1,n2,n3
+      real*8 y(n1,n2,n3),sm(n1,n2,n3),h,vext(2)
+      logical mask(n1,n2,n3)
+      integer i1,i2,i3,j1,j2,j3,ih1,ih2,ih3,ni
+      real*8 m2
+      ih1=int(h)
+      ih2=int(h*vext(1))
+      ih3=int(h*vext(2))
+      Do i1=1,n1
+         Do i2=1,n2
+            Do i3=1,n3
+               if(mask(i1,i2,i3)) THEN
+                  ni=0
+                  m2=0.d0
+                  DO j1=i1-ih1,i1+ih1
+                     if(j1.le.0.or.j1.gt.n1) CYCLE
+                     DO j2=i2-ih2,i2+ih2   
+                        if(j2.le.0.or.j2.gt.n2) CYCLE
+                        DO j3=i3-ih3,i3+ih3
+                           if(j3.le.0.or.j3.gt.n3) CYCLE
+                           if(mask(j1,j2,j3)) THEN
+                              m2=m2+y(j1,j2,j3)*y(j1,j2,j3)
+                              ni=ni+1
+                           ENDIF
+                        END DO
+                     END DO
+                  END DO
+                  sm(i1,i2,i3)=m2/ni
+               ELSE
+                  sm(i1,i2,i3)=0.d0
+               ENDIF
+            END DO
+         END DO
+      END DO
+      RETURN
+      END
